import { ElementData } from "./types/index";
/**
 * Simple API to detect and highlight interactive elements on web pages
 */
export declare class SimpleRabbitBrowser {
    private browser;
    private page;
    private elements;
    private textBlocks;
    private pageContext;
    private options;
    /**
     * Create a new SimpleRabbitBrowser instance
     */
    constructor(options?: {
        focusOnConsent?: boolean;
        waitTime?: number;
        logDetails?: boolean;
        earlyReturn?: boolean;
        includePageContext?: boolean;
        includeFormInputs?: boolean;
        includeTextBlocks?: boolean;
        highlightAllText?: boolean;
    });
    /**
     * Navigate to a URL and detect elements
     * @param url The URL to navigate to
     * @returns Promise resolving when navigation and detection are complete
     */
    go(url: string): Promise<void>;
    /**
     * Get detected elements
     * @returns Array of detected elements
     */
    getElements(): ElementData[];
    /**
     * Get text blocks
     * @returns Array of text blocks
     */
    getTextBlocks(): any[];
    /**
     * Get page context information including text content
     * @returns Page context object with text content
     */
    getPageContext(): any;
    /**
     * Get complete data with both elements and page context
     * @returns Object containing elements and page context
     */
    getCompleteData(): {
        elements: ElementData[];
        textBlocks: any[];
        pageContext: any;
    };
    /**
     * Close the browser if it's open
     */
    close(): Promise<void>;
}
/**
 * Global instance for simple use
 */
export declare const simpleRabbitBrowser: SimpleRabbitBrowser;
